@@ -23,6 +23,7 @@ use nix::unistd::close;
 use winapi::um::handleapi::CloseHandle;
 #[cfg(target_family = "windows")]
 use winapi::um::handleapi::INVALID_HANDLE_VALUE;
+use winapi::um::processthreadsapi::TerminateProcess;
 #[cfg(target_family = "windows")]
 use winapi::um::winnt::HANDLE;
 
@@ -507,6 +508,20 @@ impl ProcessMemory {
     pub fn base(&self) -> usize {
         self.base_address
     }
+
+    /// Kill the process by sending a forceful SIGKILL or via TerminateProcess
+    pub fn kill(&self) {
+        #[cfg(target_family = "unix")]
+        unsafe { kill(self.pid as _, SIGKILL);}
+        #[cfg(target_family = "windows")] unsafe {
+            TerminateProcess(self.handle as _, 0);
+        }
+    }
+
+    /// Get the process ID
+    pub fn pid(&self) {
+        self.pid;
+    }
 }
 
 impl Drop for ProcessMemory {
